#ifndef PLAYLISTCONTROLLER_H
#define PLAYLISTCONTROLLER_H

#include <qobject.h>

#include "playlist.h"
#include "playlistaspect.h"
#include "playbackcontroller.h"

class PlayListController : public QObject
{
    Q_OBJECT
public:
    explicit PlayListController(QObject *parent = 0);
    virtual ~PlayListController();

    MediaDatabase *mediaDatabase() { return mediaDatabase_; }
    PlaybackController *playbackController() { return playbackController_; }

    /* PlayList managing methods */

    PlayList *createPlayList(const QString &name);
    bool deletePlayList(const QString &name);

    int playListCount() const { return playLists_.count(); }
    PlayList *playList(int index) const { return playLists_.at(index); }
    PlayList *playList(const QString &name) const { return playListMap_.value(name, NULL); }

    /* PlayListAspect managing methods */

    PlayListAspect *createPlayListAspect(PlayList *playList, const QString &aspectName);
    bool deletePlayListAspect(const QString &prefix);
    bool deletePlayListAspect(PlayList *playList, const QString &aspectName);

    PlayListAspect *playListAspect(const QString &prefix) const { return playListAspectMap_.value(prefix, NULL); }
    PlayListAspect *playListAspect(const QString &playListName, const QString &aspectName);
    PlayListAspect *playListAspect(PlayList *playList, const QString &aspectName);

    void loadStates();
    void saveStates();

signals:

private slots:
    void playListDestroyed();
    void playListAspectDestroyed();

private:
    MediaDatabase *mediaDatabase_;
    PlaybackController *playbackController_;

    QList<PlayList *> playLists_;
    QHash<QString, PlayList *> playListMap_; // key: PlayList::sourceTable()

    QList<PlayListAspect *> playListAspects_;
    QHash<QString, PlayListAspect *> playListAspectMap_; // key: PlayListAspect::prefix()

};

#endif // PLAYLISTCONTROLLER_H
