#include "seekbar.h"

#include "skin.h"
#include "skinpanel.h"

#include "compathack.h"

SeekBar::SeekBar(Skin::PartsType type, const SkinManager *skinmgr, SkinPanel *parent)
	:	LayeredPaintBox(parent),
		parent_(parent),
		slider_(type, skinmgr, this),
		type_(type),
		orientation_(Horizontal)
{
	setSkin(skinmgr->skin());
	connect(skinmgr, SIGNAL(skinChanged(const Skin *)), this, SLOT(setSkin(const Skin *)));
	connect(((SkinPanel *) parent), SIGNAL(resized()), this, SLOT(skinPanelResized()));

	connect(&slider_, SIGNAL(sliderMoved(float)), this, SLOT(sliderHasMoved(float)));
	connect(&slider_, SIGNAL(sliderStepped(float)), this, SLOT(sliderHasStepped(float)));
	connect(&slider_, SIGNAL(sliderReleased(float)), this, SIGNAL(sliderReleased()));
}

void SeekBar::setSkin(const Skin *skin)
{
	parts_ = skin->lookup(type_);
	image_ = &parts_->image();
	skinPanelResized();
}

void SeekBar::paintToBuffer(QImage &buffer, const QRect &clipRect)
{
	QPainter backpainter(&buffer);
	backpainter.translate(-x(), -y());
	parent_->paintSkin(backpainter);
	backpainter.translate(x(), y());
	backpainter.end();

	LayeredPaintBox::paintToBuffer(buffer, clipRect);
}

void SeekBar::skinPanelResized()
{
	setGeometry(parent_->calculateGeometry(parts_));
	slider_.setGeometry(QRect(0, 0, width(), height()));
}
